@@ -24,7 +24,7 @@ fn main() -> wry::Result<()> {
     .build()?;
 
   event_loop.run(move |event, _, control_flow| {
-    *control_flow = ControlFlow::Poll;
+    *control_flow = ControlFlow::Wait;
 
     match event {
       Event::WindowEvent {
